==> hx_components_flutter-1.0.0.tar.gz: lib/src/widgets/hx_radio_button.dart <==
import 'package:flutter/material.dart';

import 'package:hx_components_flutter/src/shared/app_colors.dart';

import 'package:hx_components_flutter/src/widgets/hx_text.dart';

class HxRadioButton<T> extends StatefulWidget {
  final T value;
  final T? groupValue;
  final ValueChanged<T?> onChanged;
  final String label;
  bool toggleable;
  bool autofocus;
  Color? hoverColor;
  Color? activeColor;
  MaterialTapTargetSize? materialTapTargetSize;
  double? splashRadius;
  VisualDensity? visualDensity;
  Color borderColor;
  Color backgroundColor;
  Color checkboxBackgroundColor;
  Color textColor;

  HxRadioButton.light({
    required this.label,
    required this.value,
    this.activeColor,
    this.materialTapTargetSize,
    this.splashRadius,
    this.hoverColor,
    this.visualDensity,
    this.autofocus = false,
    this.groupValue,
    this.toggleable = true,
    required this.onChanged,
  })  : borderColor = kcGrey,
        checkboxBackgroundColor = kcBackgroundColor,
        backgroundColor = kcLightGrey,
        textColor = kcMainText;

  HxRadioButton.dark({
    required this.label,
    required this.value,
    this.activeColor,
    this.materialTapTargetSize,
    this.splashRadius,
    this.hoverColor,
    this.visualDensity,
    this.autofocus = false,
    this.groupValue,
    this.toggleable = true,
    required this.onChanged,
  })  : borderColor = kcLightGrey,
        checkboxBackgroundColor = kcMainText,
        backgroundColor = kcDarkThemeGrey,
        textColor = kcBackgroundColor;

  @override
  State<HxRadioButton> createState() => _HxRadioButtonState();
}

class _HxRadioButtonState extends State<HxRadioButton> {
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          color: widget.backgroundColor,
        ),
        child: Padding(
          padding: const EdgeInsets.symmetric(vertical: 8.0, horizontal: 10.0),
          child: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              Container(
                height: 17.5,
                width: 17.5,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(100),
                  color: widget.checkboxBackgroundColor,
                ),
                child: Radio(
                  materialTapTargetSize: widget.materialTapTargetSize,
                  splashRadius: widget.splashRadius,
                  activeColor: widget.activeColor,
                  hoverColor: widget.hoverColor,
                  autofocus: widget.autofocus,
                  visualDensity: widget.visualDensity,
                  toggleable: widget.toggleable,
                  fillColor: MaterialStateProperty.all<Color>(widget.groupValue == widget.value ? kcPrimaryColor : widget.borderColor),
                  value: widget.value,
                  groupValue: widget.groupValue,
                  onChanged: widget.onChanged,
                ),
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 4.0),
                child: HxText.body(widget.label, color: widget.textColor),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> hx_components_flutter-1.0.2.tar.gz: lib/src/widgets/hx_radio_button.dart <==
import 'package:flutter/material.dart';

import 'package:hx_components_flutter/src/shared/app_colors.dart';

import 'package:hx_components_flutter/src/widgets/hx_text.dart';

class HxRadioButton<T> extends StatefulWidget {
  final T value;
  final T? groupValue;
  final ValueChanged<T?> onChanged;
  final String label;
  bool toggleable;
  bool autofocus;
  Color? hoverColor;
  Color? activeColor;
  MaterialTapTargetSize? materialTapTargetSize;
  double? splashRadius;
  VisualDensity? visualDensity;
  Color borderColor;
  Color backgroundColor;
  Color checkboxBackgroundColor;
  Color textColor;

  HxRadioButton.light({
    required this.label,
    required this.value,
    this.activeColor,
    this.materialTapTargetSize,
    this.splashRadius,
    this.hoverColor,
    this.visualDensity,
    this.autofocus = false,
    this.groupValue,
    this.toggleable = true,
    required this.onChanged,
  })  : borderColor = kcGrey,
        checkboxBackgroundColor = kcBackgroundColor,
        backgroundColor = kcLightGrey,
        textColor = kcMainText;

  HxRadioButton.dark({
    required this.label,
    required this.value,
    this.activeColor,
    this.materialTapTargetSize,
    this.splashRadius,
    this.hoverColor,
    this.visualDensity,
    this.autofocus = false,
    this.groupValue,
    this.toggleable = true,
    required this.onChanged,
  })  : borderColor = kcLightGrey,
        checkboxBackgroundColor = kcMainText,
        backgroundColor = kcDarkThemeGrey,
        textColor = kcBackgroundColor;

  @override
  State<HxRadioButton> createState() => _HxRadioButtonState();
}

class _HxRadioButtonState extends State<HxRadioButton> {
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          color: widget.backgroundColor,
        ),
        child: Padding(
          padding: const EdgeInsets.symmetric(vertical: 8.0, horizontal: 10.0),
          child: Row(
            mainAxisSize: MainAxisSize.min,
            children: [
              Container(
                height: 17.5,
                width: 17.5,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(100),
                  color: widget.checkboxBackgroundColor,
                ),
                child: Radio(
                  materialTapTargetSize: widget.materialTapTargetSize,
                  splashRadius: widget.splashRadius,
                  activeColor: widget.activeColor,
                  hoverColor: widget.hoverColor,
                  autofocus: widget.autofocus,
                  visualDensity: widget.visualDensity,
                  toggleable: widget.toggleable,
                  fillColor: MaterialStateProperty.all<Color>(widget.groupValue == widget.value ? kcPrimaryColor : widget.borderColor),
                  value: widget.value,
                  groupValue: widget.groupValue,
                  onChanged: widget.onChanged,
                ),
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 4.0),
                child: HxText(widget.label, color: widget.textColor),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
